@@ -10,7 +10,7 @@ class TestDeployment(unittest.TestCase):
         cls.deployment = amulet.Deployment(series='precise')
 
         cls.deployment.add('nagios')
-        cls.deployment.add('haproxy')
+        cls.deployment.add('haproxy', charm='cs:~marcoceppi/precise/haproxy-0')
         cls.deployment.add('rsyslog-forwarder')
         cls.deployment.relate('nagios:website', 'haproxy:reverseproxy')
         cls.deployment.relate('nagios:juju-info', 'rsyslog-forwarder:juju-info')
@@ -24,24 +24,23 @@ class TestDeployment(unittest.TestCase):
         except:
             raise
 
-        cls.nagios = cls.deployment.sentry['nagios/0']
-        cls.haproxy = cls.deployment.sentry['haproxy/0']
-        cls.rsyslogfwd = cls.deployment.sentry['rsyslog-forwarder/0']
+        cls.nagios = cls.deployment.sentry['nagios'][0]
+        cls.haproxy = cls.deployment.sentry['haproxy'][0]
+        cls.rsyslogfwd = cls.deployment.sentry['rsyslog-forwarder'][0]
         cls.nagios.run(
-            'mkdir -p /tmp/amulet-test/test-dir;'
+            'sudo mkdir -p /tmp/amulet-test/test-dir;'
+            'sudo chmod go-rx /tmp/amulet-test;'
             'echo contents > /tmp/amulet-test/test-file;'
         )
         cls.rsyslogfwd.run(
             'echo more-contents > /tmp/amulet-sub-test;'
         )
 
-
     def test_add_unit(self):
-         self.deployment.add_unit('haproxy')
-         haproxy = self.deployment.sentry['haproxy/1']
-         self.assertEqual('1', haproxy.info['unit'])
-         self.assertEqual('haproxy/1', haproxy.info['unit_name'])
-
+        self.deployment.add_unit('haproxy')
+        haproxy = self.deployment.sentry['haproxy/1']
+        self.assertEqual('1', haproxy.info['unit'])
+        self.assertEqual('haproxy/1', haproxy.info['unit_name'])
 
     def test_info(self):
         self.assertTrue('public-address' in self.nagios.info)
@@ -61,6 +60,8 @@ class TestDeployment(unittest.TestCase):
                 'mode': '0100644',
             },
         )
+        stat = self.nagios.file_stat('metadata.yaml')
+        self.assertTrue(stat.pop('mtime'))
 
     def test_file_contents(self):
         path = '/tmp/amulet-test/test-file'
@@ -68,6 +69,7 @@ class TestDeployment(unittest.TestCase):
             self.nagios.file_contents(path),
             'contents\n',
         )
+        self.assertIn('nagios', self.nagios.file_contents('metadata.yaml'))
 
     def test_subordinate_file_contents(self):
         path = '/tmp/amulet-sub-test'
@@ -75,6 +77,7 @@ class TestDeployment(unittest.TestCase):
             self.rsyslogfwd.file_contents(path),
             'more-contents\n',
         )
+        self.assertIn('rsyslog', self.rsyslogfwd.file_contents('metadata.yaml'))
 
     def test_directory_stat(self):
         path = '/tmp/amulet-test'
@@ -91,9 +94,11 @@ class TestDeployment(unittest.TestCase):
                 'size': stat['size'],
                 'uid': 0,
                 'gid': 0,
-                'mode': '040755',
+                'mode': '040700',
             },
         )
+        stat = self.nagios.directory_stat('hooks')
+        self.assertTrue(stat.pop('mtime'))
 
     def test_directory_listing(self):
         path = '/tmp/amulet-test'
@@ -103,6 +108,7 @@ class TestDeployment(unittest.TestCase):
                 'directories': ['test-dir'],
             },
         )
+        self.assertIn('install', self.nagios.directory_listing('hooks')['files'])
 
     def test_relation(self):
         nagios_info = self.nagios.relation(
